import { Construct } from "constructs";
/**
 * Specifies the feature set supported by the new organization.
 *
 * Each feature set supports different levels of functionality.
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set
 * @stability stable
 */
export declare enum FeatureSet {
    /**
     * All member accounts have their bills consolidated to and paid by the management account.
     *
     * For more information, see [Consolidated billing]{@link https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set-cb-only} in the AWS Organizations User Guide. The consolidated billing feature subset isn’t available for organizations in the AWS GovCloud (US) Region.
     *
     * @stability stable
     */
    CONSOLIDATED_BILLING = "CONSOLIDATED_BILLING",
    /**
     * In addition to all the features supported by the consolidated billing feature set, the management account can also apply any policy type to any member account in the organization.
     *
     * For more information, see [All features]{@link https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set-all} in the AWS Organizations User Guide.
     *
     * @stability stable
     */
    ALL = "ALL"
}
/**
 * @stability stable
 */
export interface OrganizationProps {
    /**
     * Enabling features in your organization.
     *
     * @default ALL
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html
     * @stability stable
     */
    readonly featureSet?: FeatureSet;
}
/**
 * Creates an organization to consolidate your AWS accounts so that you can administer them as a single unit.
 *
 * An organization has one management account along with zero or more member accounts. You can organize the accounts in a hierarchical, tree-like structure with a root at the top and organizational units nested under the root. Each account can be directly in the root, or placed in one of the OUs in the hierarchy. An organization has the functionality that is determined by the feature set that you enable.
 *
 * <strong>For deletion of an organization you must previously remove all the member accounts, OUs, and policies from the organization!</strong>
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_create.html#create-org
 * @stability stable
 */
export declare class Organization extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: OrganizationProps);
}
